@@ -1,12 +1,12 @@
 #include "hydra-mod.h"
 #include "sasl.h"
 
-//openssl s_client -starttls pop3 -crlf -connect 192.168.0.10:110
+// openssl s_client -starttls pop3 -crlf -connect 192.168.0.10:110
 
 typedef struct pool_str {
   char ip[36];
 
-  /*  int32_t port;*/// not needed
+  /*  int32_t port;*/ // not needed
   int32_t pop3_auth_mechanism;
   int32_t disable_tls;
   struct pool_str *next;
@@ -18,7 +18,7 @@ char apop_challenge[300] = "";
 pool *plist = NULL, *p = NULL;
 
 /* functions */
-int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname);
+int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname);
 
 pool *list_create(pool data) {
   pool *p;
@@ -27,7 +27,7 @@ pool *list_create(pool data) {
     return NULL;
 
   memcpy(p->ip, data.ip, 36);
-  //p->port = data.port;
+  // p->port = data.port;
   p->pop3_auth_mechanism = data.pop3_auth_mechanism;
   p->disable_tls = data.disable_tls;
   p->next = NULL;
@@ -40,7 +40,7 @@ pool *list_insert(pool data) {
 
   newnode = list_create(data);
   newnode->next = plist;
-  plist = newnode->next;        // to be sure!
+  plist = newnode->next; // to be sure!
 
   return newnode;
 }
@@ -59,7 +59,7 @@ pool *list_find(char *ip) {
 
 /* how to know when to release the mem ?
    -> well, after _start has determined which pool number it is */
-int32_t list_remove(pool * node) {
+int32_t list_remove(pool *node) {
   pool *save, *list = plist;
   int32_t ok = -1;
 
@@ -88,18 +88,18 @@ char *pop3_read_server_capacity(int32_t sock) {
       free(buf);
     ptr = buf = hydra_receive_line(sock);
     if (buf != NULL) {
+      /*
+      exchange capa:
 
-/*
-exchange capa:
+      +OK
+      UIDL
+      STLS
 
-+OK
-UIDL
-STLS
-
-*/
+      */
       if (strstr(buf, "\r\n.\r\n") != NULL && buf[0] == '+') {
         resp = 1;
-        /* we got the capability info then get the completed warning info from server */
+        /* we got the capability info then get the completed warning info from
+         * server */
         while (hydra_data_ready(sock)) {
           free(buf);
           buf = hydra_receive_line(sock);
@@ -117,8 +117,8 @@ STLS
   return buf;
 }
 
-int32_t start_pop3(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE * fp) {
-  char *empty = "\"\"";
+int32_t start_pop3(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE *fp) {
+  char *empty = "\"\"", *result = NULL;
   char *login, *pass, buffer[500], buffer2[500], *fooptr;
 
   if (strlen(login = hydra_get_next_login()) == 0)
@@ -134,235 +134,234 @@ int32_t start_pop3(int32_t s, char *ip, int32_t port, unsigned char options, cha
 
   switch (p->pop3_auth_mechanism) {
 #ifdef LIBOPENSSL
-  case AUTH_APOP:{
-      MD5_CTX c;
-      unsigned char md5_raw[MD5_DIGEST_LENGTH];
-      int32_t i;
-      char *pbuffer = buffer2;
+  case AUTH_APOP: {
+    MD5_CTX c;
+    unsigned char md5_raw[MD5_DIGEST_LENGTH];
+    int32_t i;
+    char *pbuffer = buffer2;
 
-      MD5_Init(&c);
-      MD5_Update(&c, apop_challenge, strlen(apop_challenge));
-      MD5_Update(&c, pass, strlen(pass));
-      MD5_Final(md5_raw, &c);
+    MD5_Init(&c);
+    MD5_Update(&c, apop_challenge, strlen(apop_challenge));
+    MD5_Update(&c, pass, strlen(pass));
+    MD5_Final(md5_raw, &c);
 
-      for (i = 0; i < MD5_DIGEST_LENGTH; i++) {
-        sprintf(pbuffer, "%02x", md5_raw[i]);
-        pbuffer += 2;
-      }
-      sprintf(buffer, "APOP %s %s\r\n", login, buffer2);
+    for (i = 0; i < MD5_DIGEST_LENGTH; i++) {
+      sprintf(pbuffer, "%02x", md5_raw[i]);
+      pbuffer += 2;
     }
-    break;
+    sprintf(buffer, "APOP %s %s\r\n", login, buffer2);
+  } break;
 #endif
 
-  case AUTH_LOGIN:{
-      sprintf(buffer, "AUTH LOGIN\r\n");
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 4;
-      if (buf[0] != '+') {
-        hydra_report(stderr, "[ERROR] POP3 LOGIN AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
-      free(buf);
-      strcpy(buffer2, login);
-      hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
-
-      sprintf(buffer, "%.250s\r\n", buffer2);
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 4;
-
-      if (buf[0] != '+') {
-        hydra_report(stderr, "[ERROR] POP3 LOGIN AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
-      free(buf);
-      strcpy(buffer2, pass);
-      hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
-      sprintf(buffer, "%.250s\r\n", buffer2);
+  case AUTH_LOGIN: {
+    sprintf(buffer, "AUTH LOGIN\r\n");
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
     }
-    break;
-
-  case AUTH_PLAIN:{
-      sprintf(buffer, "AUTH PLAIN\r\n");
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 4;
-      if (buf[0] != '+') {
-        hydra_report(stderr, "[ERROR] POP3 PLAIN AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 4;
+    if (buf[0] != '+') {
+      hydra_report(stderr, "[ERROR] POP3 LOGIN AUTH : %s\n", buf);
       free(buf);
-
-      memset(buffer, 0, sizeof(buffer));
-      sasl_plain(buffer, login, pass);
-
-      char tmp_buffer[sizeof(buffer)];
-      sprintf(tmp_buffer, "%.250s\r\n", buffer);
-      strcpy(buffer, tmp_buffer);
+      return 3;
     }
-    break;
+    free(buf);
+    strcpy(buffer2, login);
+    hydra_tobase64((unsigned char *)buffer2, strlen(buffer2), sizeof(buffer2));
+
+    sprintf(buffer, "%.250s\r\n", buffer2);
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
+    }
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 4;
+
+    if (buf[0] != '+') {
+      hydra_report(stderr, "[ERROR] POP3 LOGIN AUTH : %s\n", buf);
+      free(buf);
+      return 3;
+    }
+    free(buf);
+    strcpy(buffer2, pass);
+    hydra_tobase64((unsigned char *)buffer2, strlen(buffer2), sizeof(buffer2));
+    sprintf(buffer, "%.250s\r\n", buffer2);
+  } break;
+
+  case AUTH_PLAIN: {
+    sprintf(buffer, "AUTH PLAIN\r\n");
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
+    }
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 4;
+    if (buf[0] != '+') {
+      hydra_report(stderr, "[ERROR] POP3 PLAIN AUTH : %s\n", buf);
+      free(buf);
+      return 3;
+    }
+    free(buf);
+
+    memset(buffer, 0, sizeof(buffer));
+    result = sasl_plain(buffer, login, pass);
+    if (result == NULL)
+      return 3;
+
+    char tmp_buffer[sizeof(buffer)];
+    sprintf(tmp_buffer, "%.250s\r\n", buffer);
+    strcpy(buffer, tmp_buffer);
+  } break;
 
 #ifdef LIBOPENSSL
   case AUTH_CRAMMD5:
   case AUTH_CRAMSHA1:
-  case AUTH_CRAMSHA256:{
-      int32_t rc = 0;
-      char *preplogin;
+  case AUTH_CRAMSHA256: {
+    int32_t rc = 0;
+    char *preplogin;
 
-      rc = sasl_saslprep(login, SASL_ALLOW_UNASSIGNED, &preplogin);
-      if (rc) {
-        return 3;
-      }
+    rc = sasl_saslprep(login, SASL_ALLOW_UNASSIGNED, &preplogin);
+    if (rc) {
+      return 3;
+    }
 
+    switch (p->pop3_auth_mechanism) {
+    case AUTH_CRAMMD5:
+      sprintf(buffer, "AUTH CRAM-MD5\r\n");
+      break;
+    case AUTH_CRAMSHA1:
+      sprintf(buffer, "AUTH CRAM-SHA1\r\n");
+      break;
+    case AUTH_CRAMSHA256:
+      sprintf(buffer, "AUTH CRAM-SHA256\r\n");
+      break;
+    }
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
+      return 1;
+    }
+    // get the one-time BASE64 encoded challenge
+
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 4;
+    if (buf[0] != '+') {
       switch (p->pop3_auth_mechanism) {
       case AUTH_CRAMMD5:
-        sprintf(buffer, "AUTH CRAM-MD5\r\n");
+        hydra_report(stderr, "[ERROR] POP3 CRAM-MD5 AUTH : %s\n", buf);
         break;
       case AUTH_CRAMSHA1:
-        sprintf(buffer, "AUTH CRAM-SHA1\r\n");
+        hydra_report(stderr, "[ERROR] POP3 CRAM-SHA1 AUTH : %s\n", buf);
         break;
       case AUTH_CRAMSHA256:
-        sprintf(buffer, "AUTH CRAM-SHA256\r\n");
+        hydra_report(stderr, "[ERROR] POP3 CRAM-SHA256 AUTH : %s\n", buf);
         break;
       }
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
-        return 1;
-      }
-      //get the one-time BASE64 encoded challenge
-
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 4;
-      if (buf[0] != '+') {
-        switch (p->pop3_auth_mechanism) {
-        case AUTH_CRAMMD5:
-          hydra_report(stderr, "[ERROR] POP3 CRAM-MD5 AUTH : %s\n", buf);
-          break;
-        case AUTH_CRAMSHA1:
-          hydra_report(stderr, "[ERROR] POP3 CRAM-SHA1 AUTH : %s\n", buf);
-          break;
-        case AUTH_CRAMSHA256:
-          hydra_report(stderr, "[ERROR] POP3 CRAM-SHA256 AUTH : %s\n", buf);
-          break;
-        }
-        free(buf);
-        return 3;
-      }
-
-      memset(buffer, 0, sizeof(buffer));
-      from64tobits((char *) buffer, buf + 2);
       free(buf);
-
-      memset(buffer2, 0, sizeof(buffer2));
-
-      switch (p->pop3_auth_mechanism) {
-      case AUTH_CRAMMD5:{
-          sasl_cram_md5(buffer2, pass, buffer);
-          sprintf(buffer, "%s %.250s", preplogin, buffer2);
-        }
-        break;
-      case AUTH_CRAMSHA1:{
-          sasl_cram_sha1(buffer2, pass, buffer);
-          sprintf(buffer, "%s %.250s", preplogin, buffer2);
-        }
-        break;
-      case AUTH_CRAMSHA256:{
-          sasl_cram_sha256(buffer2, pass, buffer);
-          sprintf(buffer, "%s %.250s", preplogin, buffer2);
-        }
-        break;
-      }
-      hydra_tobase64((unsigned char *) buffer, strlen(buffer), sizeof(buffer));
-
-      char tmp_buffer[sizeof(buffer)];
-      sprintf(tmp_buffer, "%.250s\r\n", buffer);
-      strcpy(buffer, tmp_buffer);
-      free(preplogin);
+      return 3;
     }
-    break;
 
-  case AUTH_DIGESTMD5:{
-      sprintf(buffer, "AUTH DIGEST-MD5\r\n");
+    memset(buffer, 0, sizeof(buffer));
+    from64tobits((char *)buffer, buf + 2);
+    free(buf);
 
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
-        return 1;
-      //receive
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 4;
-      if (buf[0] != '+') {
-        hydra_report(stderr, "[ERROR] POP3 DIGEST-MD5 AUTH : %s\n", buf);
-        free(buf);
+    memset(buffer2, 0, sizeof(buffer2));
+
+    switch (p->pop3_auth_mechanism) {
+    case AUTH_CRAMMD5: {
+      result = sasl_cram_md5(buffer2, pass, buffer);
+      if (result == NULL)
         return 3;
-      }
-      memset(buffer, 0, sizeof(buffer));
-      from64tobits((char *) buffer, buf);
+      sprintf(buffer, "%s %.250s", preplogin, buffer2);
+    } break;
+    case AUTH_CRAMSHA1: {
+      result = sasl_cram_sha1(buffer2, pass, buffer);
+      if (result == NULL)
+        return 3;
+      sprintf(buffer, "%s %.250s", preplogin, buffer2);
+    } break;
+    case AUTH_CRAMSHA256: {
+      result = sasl_cram_sha256(buffer2, pass, buffer);
+      if (result == NULL)
+        return 3;
+      sprintf(buffer, "%s %.250s", preplogin, buffer2);
+    } break;
+    }
+    hydra_tobase64((unsigned char *)buffer, strlen(buffer), sizeof(buffer));
+
+    char tmp_buffer[sizeof(buffer)];
+    sprintf(tmp_buffer, "%.250s\r\n", buffer);
+    strcpy(buffer, tmp_buffer);
+    free(preplogin);
+  } break;
+
+  case AUTH_DIGESTMD5: {
+    sprintf(buffer, "AUTH DIGEST-MD5\r\n");
+
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
+      return 1;
+    // receive
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 4;
+    if (buf[0] != '+') {
+      hydra_report(stderr, "[ERROR] POP3 DIGEST-MD5 AUTH : %s\n", buf);
       free(buf);
-
-      if (debug)
-        hydra_report(stderr, "[DEBUG] S: %s\n", buffer);
-
-      fooptr = buffer2;
-      sasl_digest_md5(fooptr, login, pass, buffer, miscptr, "pop", NULL, 0, NULL);
-      if (fooptr == NULL)
-        return 3;
-
-      if (debug)
-        hydra_report(stderr, "[DEBUG] C: %s\n", buffer2);
-      hydra_tobase64((unsigned char *) buffer2, strlen(buffer2), sizeof(buffer2));
-      sprintf(buffer, "%s\r\n", buffer2);
+      return 3;
     }
-    break;
+    memset(buffer, 0, sizeof(buffer));
+    from64tobits((char *)buffer, buf);
+    free(buf);
+
+    if (debug)
+      hydra_report(stderr, "[DEBUG] S: %s\n", buffer);
+
+    fooptr = buffer2;
+    result = sasl_digest_md5(fooptr, login, pass, buffer, miscptr, "pop", NULL, 0, NULL);
+    if (result == NULL)
+      return 3;
+
+    if (debug)
+      hydra_report(stderr, "[DEBUG] C: %s\n", buffer2);
+    hydra_tobase64((unsigned char *)buffer2, strlen(buffer2), sizeof(buffer2));
+    sprintf(buffer, "%s\r\n", buffer2);
+  } break;
 #endif
 
-  case AUTH_NTLM:{
-      unsigned char buf1[4096];
-      unsigned char buf2[4096];
+  case AUTH_NTLM: {
+    unsigned char buf1[4096];
+    unsigned char buf2[4096];
 
-      //Send auth request
-      sprintf(buffer, "AUTH NTLM\r\n");
+    // Send auth request
+    sprintf(buffer, "AUTH NTLM\r\n");
 
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
-        return 1;
-      //receive
-      if ((buf = hydra_receive_line(s)) == NULL)
-        return 4;
-      if (buf[0] != '+') {
-        hydra_report(stderr, "[ERROR] POP3 NTLM AUTH : %s\n", buf);
-        free(buf);
-        return 3;
-      }
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
+      return 1;
+    // receive
+    if ((buf = hydra_receive_line(s)) == NULL)
+      return 4;
+    if (buf[0] != '+') {
+      hydra_report(stderr, "[ERROR] POP3 NTLM AUTH : %s\n", buf);
       free(buf);
-      //send auth and receive challenge
-      //send auth request: lst the server send it's own hostname and domainname
-      buildAuthRequest((tSmbNtlmAuthRequest *) buf2, 0, NULL, NULL);
-      to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthRequest *) buf2));
-
-      sprintf(buffer, "%s\r\n", buf1);
-      if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
-        return 1;
-      if ((buf = hydra_receive_line(s)) == NULL || strlen(buf) < 6)
-        return 4;
-
-      //recover challenge
-      from64tobits((char *) buf1, buf + 2);
-      free(buf);
-
-      //Send response
-      buildAuthResponse((tSmbNtlmAuthChallenge *) buf1, (tSmbNtlmAuthResponse *) buf2, 0, login, pass, NULL, NULL);
-      to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthResponse *) buf2));
-
-      sprintf(buffer, "%s\r\n", buf1);
+      return 3;
     }
-    break;
+    free(buf);
+    // send auth and receive challenge
+    // send auth request: lst the server send it's own hostname and domainname
+    buildAuthRequest((tSmbNtlmAuthRequest *)buf2, 0, NULL, NULL);
+    to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthRequest *)buf2));
+
+    sprintf(buffer, "%s\r\n", buf1);
+    if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
+      return 1;
+    if ((buf = hydra_receive_line(s)) == NULL || strlen(buf) < 6)
+      return 4;
+
+    // recover challenge
+    from64tobits((char *)buf1, buf + 2);
+    free(buf);
+
+    // Send response
+    buildAuthResponse((tSmbNtlmAuthChallenge *)buf1, (tSmbNtlmAuthResponse *)buf2, 0, login, pass, NULL, NULL);
+    to64frombits(buf1, buf2, SmbLength((tSmbNtlmAuthResponse *)buf2));
+
+    sprintf(buffer, "%s\r\n", buf1);
+  } break;
   default:
     sprintf(buffer, "USER %.250s\r\n", login);
     if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
@@ -413,11 +412,11 @@ int32_t start_pop3(int32_t s, char *ip, int32_t port, unsigned char options, cha
   return 2;
 }
 
-void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   int32_t run = 1, next_run = 1, sock = -1;
   char *ptr = NULL;
 
-  //extract data from the pool, ip is the key
+  // extract data from the pool, ip is the key
   if (plist == NULL)
     if (service_pop3_init(ip, sp, options, miscptr, fp, port, hostname) != 0)
       hydra_child_exit(2);
@@ -433,10 +432,9 @@ void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
   if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
     return;
 
-
   while (1) {
     switch (run) {
-    case 1:                    /* connect and service init function */
+    case 1: /* connect and service init function */
 
       if (sock >= 0)
         sock = hydra_disconnect(sock);
@@ -448,11 +446,11 @@ void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
       }
       if (sock < 0) {
         if (verbose || debug)
-          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t) getpid());
+          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t)getpid());
         hydra_child_exit(1);
       }
       buf = hydra_receive_line(sock);
-      if (buf == NULL || buf[0] != '+') {       /* check the first line */
+      if (buf == NULL || buf[0] != '+') { /* check the first line */
         if (verbose || debug)
           hydra_report(stderr, "[ERROR] Not an POP3 protocol or service shutdown: %s\n", buf);
         hydra_child_exit(2);
@@ -470,11 +468,13 @@ void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
 
 #ifdef LIBOPENSSL
       if (!p->disable_tls) {
-        /* check for STARTTLS, if available we may have access to more basic auth methods */
+        /* check for STARTTLS, if available we may have access to more basic
+         * auth methods */
         hydra_send(sock, "STLS\r\n", strlen("STLS\r\n"), 0);
         buf = hydra_receive_line(sock);
         if (buf[0] != '+') {
-          hydra_report(stderr, "[ERROR] TLS negotiation failed, no answer received from STARTTLS request\n");
+          hydra_report(stderr, "[ERROR] TLS negotiation failed, no answer "
+                               "received from STARTTLS request\n");
         } else {
           free(buf);
           if ((hydra_connect_to_ssl(sock, hostname) == -1)) {
@@ -491,15 +491,15 @@ void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
 
       next_run = 2;
       break;
-    case 2:                    /* run the cracking function */
+    case 2: /* run the cracking function */
       next_run = start_pop3(sock, ip, port, options, miscptr, fp);
       break;
-    case 3:                    /* clean exit */
+    case 3: /* clean exit */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       hydra_child_exit(0);
       return;
-    case 4:                    /* clean exit */
+    case 4: /* clean exit */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       hydra_child_exit(2);
@@ -512,8 +512,7 @@ void service_pop3(char *ip, int32_t sp, unsigned char options, char *miscptr, FI
   }
 }
 
-
-int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   int32_t myport = PORT_POP3, mysslport = PORT_POP3_SSL;
   char *ptr = NULL;
   int32_t sock = -1;
@@ -523,6 +522,7 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
 
   p.pop3_auth_mechanism = AUTH_CLEAR;
   p.disable_tls = 1;
+  p.next = NULL;
   memcpy(p.ip, ip, 36);
 
   if ((options & OPTION_SSL) == 0) {
@@ -536,11 +536,11 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
   }
   if (sock < 0) {
     if (verbose || debug)
-      hydra_report(stderr, "[ERROR] pid %d terminating, can not connect\n", (int32_t) getpid());
+      hydra_report(stderr, "[ERROR] pid %d terminating, can not connect\n", (int32_t)getpid());
     return -1;
   }
   buf = hydra_receive_line(sock);
-  if (buf == NULL || buf[0] != '+') {   /* check the first line */
+  if (buf == NULL || buf[0] != '+') { /* check the first line */
     if (verbose || debug)
       hydra_report(stderr, "[ERROR] Not an POP3 protocol or service shutdown: %s\n", buf);
     return -1;
@@ -574,7 +574,7 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
     int32_t i;
 
     for (i = 0; i < strlen(miscptr); i++)
-      miscptr[i] = (char) toupper((int32_t) miscptr[i]);
+      miscptr[i] = (char)toupper((int32_t)miscptr[i]);
 
     if (strstr(miscptr, "TLS") || strstr(miscptr, "SSL") || strstr(miscptr, "STARTTLS")) {
       p.disable_tls = 0;
@@ -583,13 +583,15 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
 
 #ifdef LIBOPENSSL
   if (!p.disable_tls) {
-    /* check for STARTTLS, if available we may have access to more basic auth methods */
+    /* check for STARTTLS, if available we may have access to more basic auth
+     * methods */
     if (strstr(buf, "STLS") != NULL) {
       hydra_send(sock, "STLS\r\n", strlen("STLS\r\n"), 0);
       free(buf);
       buf = hydra_receive_line(sock);
       if (buf[0] != '+') {
-        hydra_report(stderr, "[ERROR] TLS negotiation failed, no answer received from STARTTLS request\n");
+        hydra_report(stderr, "[ERROR] TLS negotiation failed, no answer "
+                             "received from STARTTLS request\n");
       } else {
         free(buf);
         if ((hydra_connect_to_ssl(sock, hostname) == -1)) {
@@ -615,16 +617,16 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
         }
       }
     } else
-      hydra_report(stderr, "[ERROR] option to use TLS/SSL failed as it is not supported by the server\n");
+      hydra_report(stderr, "[ERROR] option to use TLS/SSL failed as it is not "
+                           "supported by the server\n");
   }
 #endif
 
   if (hydra_send(sock, quit_str, strlen(quit_str), 0) < 0) {
-    //we don't care if the server is not receiving the quit msg
+    // we don't care if the server is not receiving the quit msg
   }
   hydra_disconnect(sock);
 
-
   if (verbose)
     hydra_report(stderr, "[VERBOSE] CAPABILITY: %s", buf);
 
@@ -647,7 +649,8 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
      which are supported.
    */
 
-  /* which mean threre will *always* have a space before the LOGIN auth keyword */
+  /* which mean threre will *always* have a space before the LOGIN auth keyword
+   */
   if ((strstr(buf, " LOGIN") == NULL) && (strstr(buf, "NTLM") != NULL)) {
     p.pop3_auth_mechanism = AUTH_NTLM;
   }
@@ -687,12 +690,10 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
 #else
     p.pop3_auth_mechanism = AUTH_CLEAR;
 #endif
-
   }
   free(buf);
 
   if ((miscptr != NULL) && (strlen(miscptr) > 0)) {
-
     if (strstr(miscptr, "CLEAR"))
       p.pop3_auth_mechanism = AUTH_CLEAR;
 
@@ -721,7 +722,6 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
 
     if (strstr(miscptr, "NTLM"))
       p.pop3_auth_mechanism = AUTH_NTLM;
-
   }
 
   if (verbose) {
@@ -764,7 +764,6 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
     case AUTH_NTLM:
       hydra_report(stderr, "[VERBOSE] using POP3 NTLM AUTH mechanism\n");
       break;
-
     }
   }
 
@@ -776,8 +775,11 @@ int32_t service_pop3_init(char *ip, int32_t sp, unsigned char options, char *mis
   return 0;
 }
 
-void usage_pop3(const char* service) {
+void usage_pop3(const char *service) {
   printf("Module pop3 is optionally taking one authentication type of:\n"
          "  CLEAR (default), LOGIN, PLAIN, CRAM-MD5, CRAM-SHA1,\n"
-         "  CRAM-SHA256, DIGEST-MD5, NTLM.\n" "Additionally TLS encryption via STLS can be enforced with the TLS option.\n\n" "Example: pop3://target/TLS:PLAIN\n");
+         "  CRAM-SHA256, DIGEST-MD5, NTLM.\n"
+         "Additionally TLS encryption via STLS can be enforced with the TLS "
+         "option.\n\n"
+         "Example: pop3://target/TLS:PLAIN\n");
 }
