@@ -6,7 +6,7 @@
 extern char *HYDRA_EXIT;
 char *buf;
 
-int32_t start_rpcap(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE * fp) {
+int32_t start_rpcap(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE *fp) {
   char *empty = "";
   char *login, *pass, buffer[1024];
 
@@ -21,7 +21,8 @@ int32_t start_rpcap(int32_t s, char *ip, int32_t port, unsigned char options, ch
   char bfr4[] = " ";
   bfr4[0] = strlen(login) + strlen(pass) + 8;
   char bfr5[] = "\x00";
-  char bfr6[] = "\x01";   // x01 - when a password is required, x00 - when no need of password
+  char bfr6[] = "\x01"; // x01 - when a password is required, x00 - when no need
+                        // of password
   char bfr7[] = "\x00\x00\x00";
   char bfr8[] = " ";
   bfr8[0] = strlen(login);
@@ -57,13 +58,12 @@ int32_t start_rpcap(int32_t s, char *ip, int32_t port, unsigned char options, ch
       return 3;
     return 1;
   }
-/*
-  if (strstr(buf, "Logon failure") == NULL) {
-    hydra_report(stderr, "[ERROR] rpcap error or service shutdown: %s\n", buf);
-    free(buf);
-    return 4;
-  }
-*/
+  /*
+    if (strstr(buf, "Logon failure") == NULL) {
+      hydra_report(stderr, "[ERROR] rpcap error or service shutdown: %s\n",
+    buf); free(buf); return 4;
+    }
+  */
   free(buf);
   hydra_completed_pair();
   if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
@@ -72,7 +72,7 @@ int32_t start_rpcap(int32_t s, char *ip, int32_t port, unsigned char options, ch
   return 2;
 }
 
-void service_rpcap(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+void service_rpcap(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   int32_t run = 1, next_run = 1, sock = -1;
   int32_t myport = PORT_RPCAP, mysslport = PORT_RPCAP_SSL;
 
@@ -81,10 +81,10 @@ void service_rpcap(char *ip, int32_t sp, unsigned char options, char *miscptr, F
     return;
   while (1) {
     switch (run) {
-    case 1:                    /* connect and service init function */
+    case 1: /* connect and service init function */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
-      //usleep(300000);
+      // usleep(300000);
       if ((options & OPTION_SSL) == 0) {
         if (port != 0)
           myport = port;
@@ -99,18 +99,19 @@ void service_rpcap(char *ip, int32_t sp, unsigned char options, char *miscptr, F
 
       if (sock < 0) {
         if (verbose || debug)
-          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t) getpid());
+          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t)getpid());
         hydra_child_exit(1);
       }
       next_run = 2;
       break;
-    case 2:                    /* run the cracking function */
+    case 2: /* run the cracking function */
       next_run = start_rpcap(sock, ip, port, options, miscptr, fp);
       break;
-    case 3:                    /* clean exit */
+    case 3: /* clean exit */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       hydra_child_exit(0);
+      break;
     default:
       hydra_report(stderr, "[ERROR] Caught unknown return code, exiting!\n");
       hydra_child_exit(2);
@@ -119,7 +120,7 @@ void service_rpcap(char *ip, int32_t sp, unsigned char options, char *miscptr, F
   }
 }
 
-int32_t service_rpcap_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+int32_t service_rpcap_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   // called before the childrens are forked off, performed once only.
   // return codes:
   // 0 - rpcap with authentication
